Module win

Module win 

Modules

ssd_io_context

Structs

FileHandle
Windows File Handle Wrapper
IOCompletionPort
This module provides a safe and idiomatic Rust interface over the IOCompletionPort handle and associated Windows API functions. This struct represents an I/O completion port, which is an object used in asynchronous I/O operations on Windows.
ThreadSafeHandle
ThreadSafeHandle struct that wraps a native Windows HANDLE object with a mutex to ensure thread safety.

Enums

AccessMode
AccessMode determines how a file can be accessed. These modes are used when creating or opening a file to decide what operations are allowed to be performed on the file.
ShareMode
ShareMode determines how a file can be shared.

Functions

get_number_of_processors
get_peak_workingset_size
get_process_cycle_time
get_process_time
get_queued_completion_status
Retrieves the results of an asynchronous I/O operation on an I/O completion port.
get_system_time
read_file_to_slice
Asynchronously queue a read request from a file into a buffer slice.

Type Aliases

DWORD
OVERLAPPED
ULONG_PTR