pub enum AccessMode {
Read,
Write,
ReadWrite,
}Expand description
AccessMode determines how a file can be accessed.
These modes are used when creating or opening a file to decide what operations are allowed
to be performed on the file.
Variants
-
Read: The file is opened in read-only mode. -
Write: The file is opened in write-only mode. -
ReadWrite: The file is opened for both reading and writing.
Variants