ThreadSafeHandle

Struct ThreadSafeHandle 

pub struct ThreadSafeHandle(/* private fields */);
ThreadSafeHandle struct that wraps a native Windows HANDLE object with a mutex to ensure thread safety.

Implementations

Source

impl ThreadSafeHandle

pub fn lock(&self) -> Result<MutexGuard<'_, HANDLE>>

Lock the mutex and return a guard to the handle.

pub fn new(handle: HANDLE) -> Self

Create a new ThreadSafeHandle from a native Windows HANDLE.