Modules
Structs
- File
Handle - Windows File Handle Wrapper
- IOCompletion
Port - This module provides a safe and idiomatic Rust interface over the IOCompletionPort handle and associated Windows API functions. This struct represents an I/O completion port, which is an object used in asynchronous I/O operations on Windows.
- Thread
Safe Handle ThreadSafeHandlestruct that wraps a native WindowsHANDLEobject with a mutex to ensure thread safety.
Enums
- Access
Mode AccessModedetermines how a file can be accessed. These modes are used when creating or opening a file to decide what operations are allowed to be performed on the file.- Share
Mode ShareModedetermines how a file can be shared.
Functions
- get_
number_ of_ processors - get_
peak_ workingset_ size - get_
process_ cycle_ time - get_
process_ time - get_
queued_ ⚠completion_ status - Retrieves the results of an asynchronous I/O operation on an I/O completion port.
- get_
system_ time - read_
file_ ⚠to_ slice - Asynchronously queue a read request from a file into a buffer slice.